Module fix

Module fix 

Re-exports

pub use crate::FixError;

Structs

DayOfMonth
A calendar day‐of‐month in the range 1–31.
FixedPrice
Fixed-point number with generic digits: W digits for whole part, F digits for fraction. Total W + F must be ≤ 18 to fit into i64.

Enums

DayOfMonthError
Errors that can occur when parsing or validating a day‐of‐month.

Functions

get_msg_type

Type Aliases

Price
Alias for the default Price (10 whole digits, 8 fractional digits)